/**
   PostHTTPClient.ino

    Created on: 21.11.2016

*/

#include <ESP8266WiFi.h>
#include <ESP8266HTTPClient.h>
#include <Servo.h>

/* this can be run with an emulated server on host:
        cd esp8266-core-root-dir
        cd tests/host
        make ../../libraries/ESP8266WebServer/examples/PostServer/PostServer
        bin/PostServer/PostServer
   then put your PC's IP address in SERVER_IP below, port 9080 (instead of default 80):
*/
//#define SERVER_IP "api.thingspeak.com" // PC address with emulation on host
#define SERVER_IP "api.thingspeak.com"

#ifndef STASSID
#define STASSID "SSID_WIFI"
#define STAPSK "PASS_WIFI"
#endif

#ifndef TALKBACK_ID
#define TALKBACK_ID "ID_LISTA_DE_COMANDOS"
#endif

#ifndef API_TB_KEY
#define API_TB_KEY "API_KEY_LISTA_DE_COMANDOS"
#endif

Servo servo1;

void setup() {
  
  Serial.begin(115200);
  pinMode(LED_BUILTIN, OUTPUT);
  digitalWrite(LED_BUILTIN, HIGH);
  servo1.attach(D4);
  Serial.println();
  Serial.println();
  Serial.println();

  WiFi.begin(STASSID, STAPSK);

  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
}

void loop() {
  // wait for WiFi connection
  if ((WiFi.status() == WL_CONNECTED)) {

    WiFiClient client;
    HTTPClient http;

    Serial.print("[HTTP] begin...\n");
    // configure traged server and url
    http.begin(client, "http://" SERVER_IP "/talkbacks/" TALKBACK_ID "/commands/execute");  // HTTP 
    http.addHeader("Content-Type", "application/json");

    Serial.print("[HTTP] POST...\n");
    // start connection and send HTTP header and body
    int httpCode = http.POST("{\"api_key\":\"" API_TB_KEY "\"}");

    // httpCode will be negative on error
    if (httpCode > 0) {
      // HTTP header has been send and Server response header has been handled
      Serial.printf("[HTTP] POST... code: %d\n", httpCode);

      // file found at server
      if (httpCode == HTTP_CODE_OK) {
        const String& payload = http.getString();
        
        if (strcmp(payload.c_str(),"Prender_LED")==0){
            digitalWrite(LED_BUILTIN, LOW); 
            Serial.println("LED encendido");
            for (int i = 0; i < 10; i++){
              servo1.write(0);
              delay(500);
              servo1.write(180);
              delay(500);
            }
            Serial.println("Servo-Accionado");
        }
        if (strcmp(payload.c_str(),"Apagar_LED")==0){
            digitalWrite(LED_BUILTIN, HIGH); 
            Serial.println("LED apagado");
        }
      }
    } else {
      Serial.printf("[HTTP] POST... failed, error: %s\n", http.errorToString(httpCode).c_str());
    }

    http.end();
  }

  delay(10000);
}
